# Compatibility

## Supported Browsers
Vizro supports the [Chrome Browser](https://www.google.com/intl/en_us/chrome/).
Other browsers may work, but are not officially supported.

## Versioning policy
This project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).
We do not consider frontend changes (such as changing the appearance of a component) to be breaking changes.

!!! note
    While being in version `0.x.x`, we may introduce breaking changes in minor versions.
